#define indicatorName "All Prices"

#property indicator_separate_window
#property indicator_buffers 2
#property indicator_color1  PaleVioletRed
#property indicator_width1  2
#property indicator_color2  DeepSkyBlue
#property indicator_width2  1

//---- input parameters
extern int    Price                    = PRICE_CLOSE;
extern int    MaPeriod                 =      5;
extern int    MaMethod                 = MODE_EMA;
extern string __                       = "Chose timeframes";
extern string timeFrames               = "M5;M15;M30;H1;H4";
extern int    barsPerTimeFrame         =     30;
extern bool   shiftRight               =  False;
extern bool   currentFirst             =  true; 
extern bool   equalize                 =  true;
extern color  txtColor                 = Silver; 
extern color  separatorColor           = DimGray;

//---- buffers
double Price_Buffer[];
double Ma_Buffer[];

int    Shift; 
int    limit;
int    window;  
int    periods[];
string labels[];
string shortName;
double minValue;
double maxValue;
double maxValues[];
double minValues[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+

int init()
{
      IndicatorBuffers(2);
      
         SetIndexBuffer(0,Price_Buffer);  SetIndexLabel(0,"Price");
         SetIndexBuffer(1,Ma_Buffer);     SetIndexLabel(1,"MA");

      timeFrames = StringTrimLeft(StringTrimRight(timeFrames));
         if (StringSubstr(timeFrames,StringLen(timeFrames),1) != ";")
                          timeFrames = StringConcatenate(timeFrames,";");

         int s = 0;
         int i = StringFind(timeFrames,";",s);
         int time;
         string current;
            while (i > 0)
            {
               current = StringSubstr(timeFrames,s,i-s);
               time    = stringToTimeFrame(current);
               if (time > 0) {
                     ArrayResize(labels ,ArraySize(labels) +1);
                     ArrayResize(periods,ArraySize(periods)+1);
                                 labels [ArraySize(labels)-1]  = TimeFrameToString(time); 
                                 periods[ArraySize(periods)-1] = time; }
                                 s = i + 1;
                                     i = StringFind(timeFrames,";",s);
            }
   
         if (shiftRight) Shift  = 1;
         else            Shift  = 0;
               limit            = ArraySize(periods);
               barsPerTimeFrame = MathMax(barsPerTimeFrame,30);      
         for (i=0;i<7;i++)  SetIndexShift(i,Shift*(barsPerTimeFrame+1));

      if(currentFirst)
      for (i=1; i<limit; i++)
         if (Period()==periods[i])
            {
               string tmpLbl = labels[i];
               int    tmpPer = periods[i];
               
               for (int k=i ;k>0; k--)
                     {
                        labels[k]  = labels[k-1];
                        periods[k] = periods[k-1];
                     }                     
               labels[0]  = tmpLbl;
               periods[0] = tmpPer;
            }
   
      shortName = indicatorName+" ("+MaPeriod+")";
      IndicatorShortName(shortName);
   return(0);
}


//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int deinit()
{
   for(int l=0;l<limit;l++) {
         ObjectDelete(indicatorName+window+l);
         ObjectDelete(indicatorName+window+l+" label");
      }         
   return(0);
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+

int start()
{
   static bool init = false;
   double koef = 1.0,maxRange;
   minValue =  9999999999999;
   maxValue = -9999999999999;
   string on;
   int    k=0;


   if (!init)
     {
        init      = true;
        window    = WindowFind(shortName);  
        shortName = indicatorName+window+" ("+MaPeriod+")";
            IndicatorShortName(shortName);
               ArrayResize(maxValues,limit);
               ArrayResize(minValues,limit);
     }            
     ArrayInitialize(maxValues,-99999999999999);
     ArrayInitialize(minValues, 99999999999999);

            for(int p=0; p<limit;p++)
                  {
                     for(int i=0; i<barsPerTimeFrame;i++,k++)
                           {
                              Price_Buffer[k] = iMA(NULL,periods[p],1,0,MODE_SMA,Price,i);
                              Ma_Buffer[k]    = iMA(NULL,periods[p],MaPeriod,0,MaMethod,Price,i);

                                 minValue     = MathMin(Price_Buffer[k],Ma_Buffer[k]);
                                 maxValue     = MathMax(Price_Buffer[k],Ma_Buffer[k]); 
                                 minValues[p] = MathMin(minValue,minValues[p]);
                                 maxValues[p] = MathMax(maxValue,maxValues[p]);
                           }
                           
                           Price_Buffer[k] = EMPTY_VALUE;
                           Ma_Buffer[k]    = EMPTY_VALUE;
                           k += 1;
                           
                           on = indicatorName+window+p;
                           if(ObjectFind(on)==-1)
                              ObjectCreate(on,OBJ_TREND,window,0,0);
                              ObjectSet(on,OBJPROP_TIME1,myTime(k-Shift*(barsPerTimeFrame+1)-1));
                              ObjectSet(on,OBJPROP_TIME2,myTime(k-Shift*(barsPerTimeFrame+1)-1));
                              ObjectSet(on,OBJPROP_PRICE1,maxValue*1.1);
                              ObjectSet(on,OBJPROP_PRICE2,minValue);
                              ObjectSet(on,OBJPROP_COLOR,separatorColor);
                              ObjectSet(on,OBJPROP_WIDTH,2);
                              
                           on = indicatorName+window+p+" label";
                           if(ObjectFind(on)==-1)
                              ObjectCreate(on,OBJ_TEXT,window,0,0);
                              ObjectSet(on,OBJPROP_TIME1,myTime(k-Shift*(barsPerTimeFrame+1)-6));
                              ObjectSet(on,OBJPROP_PRICE1,maxValue);
                              ObjectSetText(on,labels[p],9,"Arial",txtColor);
                  }
            k += 1;            

      if (equalize)
      {      
         minValue =  9999999999999;
         maxValue = -9999999999999;
         maxRange = 0; 
         for (p=0; p<limit; p++) if ((maxValues[p]-minValues[p])>maxRange) maxRange = maxValues[p]-minValues[p];
         for(p=0, k=0; p<limit;p++)
            {
               double coeff = maxRange/(maxValues[p]-minValues[p]);
               for(i=0; i<barsPerTimeFrame;i++,k++)
               {
                  Price_Buffer[k] = coeff*(Price_Buffer[k]-minValues[p]);
                  Ma_Buffer[k]    = coeff*(Ma_Buffer[k]   -minValues[p]);
             
                  minValue = MathMin(MathMin(Price_Buffer[k],Ma_Buffer[k]),minValue);
                  maxValue = MathMax(MathMax(Price_Buffer[k],Ma_Buffer[k]),maxValue);
               }                     
               k += 1;
            }

         for(p=0; p<limit;p++)
            {
               on = indicatorName+window+p;
                  ObjectSet(on,OBJPROP_PRICE1,maxValue*1.1);
                  ObjectSet(on,OBJPROP_PRICE2,minValue);
               on = indicatorName+window+p+" label";
                  ObjectSet(on,OBJPROP_PRICE1,maxValue);
            }
      }

      for (i=0;i<7;i++) SetIndexDrawBegin(i,Bars-k);

   return(0);
}


//+------------------------------------------------------------------+
//+                                                                  +
//+------------------------------------------------------------------+

int myTime(int a)
{
   if(a<0)
         return(Time[0]+Period()*60*MathAbs(a));
   else  return(Time[a]);   
}


//+------------------------------------------------------------------+
//+                                                                  +
//+------------------------------------------------------------------+


int stringToTimeFrame(string tfs)
{
   int tf=0;
       tfs = StringUpperCase(tfs);
       
         if (tfs=="M1" || tfs=="1")     tf=PERIOD_M1;
         if (tfs=="M5" || tfs=="5")     tf=PERIOD_M5;
         if (tfs=="M15"|| tfs=="15")    tf=PERIOD_M15;
         if (tfs=="M30"|| tfs=="30")    tf=PERIOD_M30;
         if (tfs=="H1" || tfs=="60")    tf=PERIOD_H1;
         if (tfs=="H4" || tfs=="240")   tf=PERIOD_H4;
         if (tfs=="D1" || tfs=="1440")  tf=PERIOD_D1;
         if (tfs=="W1" || tfs=="10080") tf=PERIOD_W1;
         if (tfs=="MN" || tfs=="43200") tf=PERIOD_MN1;
         
   return(tf);
}


string TimeFrameToString(int tf)
{
   string tfs="Current time frame";
   switch(tf)
   {
      case PERIOD_M1:  tfs="M1"  ; break;
      case PERIOD_M5:  tfs="M5"  ; break;
      case PERIOD_M15: tfs="M15" ; break;
      case PERIOD_M30: tfs="M30" ; break;
      case PERIOD_H1:  tfs="H1"  ; break;
      case PERIOD_H4:  tfs="H4"  ; break;
      case PERIOD_D1:  tfs="D1"  ; break;
      case PERIOD_W1:  tfs="W1"  ; break;
      case PERIOD_MN1: tfs="MN";
   }
   return(tfs);
}


string StringUpperCase(string str)
{
   string   s = str;
   int      lenght = StringLen(str) - 1;
   int      Char;
   
   while(lenght >= 0)
   {
         Char = StringGetChar(s, lenght);

         if((Char > 96 && Char < 123) || (Char > 223 && Char < 256))
                  s = StringSetChar(s, lenght, Char - 32);
          else 
              if(Char > -33 && Char < 0)
                  s = StringSetChar(s, lenght, Char + 224);
                                 
         lenght--;
   }
   
   return(s);
}

//+------------------------------------------------------------------+
//+                                                                  +
//+------------------------------------------------------------------+